@@ -4,12 +4,11 @@ import os
 import sys
 import json
 import getpass
+import configparser
 
-from six.moves import configparser
+from jaraco.classes import properties
 
-from keyring.util import properties
 from .escape import escape as escape_for_ini
-
 from keyrings.alt.file_base import Keyring, decodebytes, encodebytes
 
 
@@ -24,34 +23,44 @@ class PlaintextKeyring(Keyring):
     version = '1.0'
 
     def encrypt(self, password, assoc=None):
-        """Directly return the password itself, ignore associated data.
-        """
+        """Directly return the password itself, ignore associated data."""
         return password
 
     def decrypt(self, password_encrypted, assoc=None):
-        """Directly return encrypted password, ignore associated data.
-        """
+        """Directly return encrypted password, ignore associated data."""
         return password_encrypted
 
 
-class Encrypted(object):
+class Encrypted:
     """
-    PyCrypto-backed Encryption support
+    PyCryptodome-backed Encryption support
     """
 
     scheme = '[PBKDF2] AES256.CFB'
     version = '1.0'
     block_size = 32
 
+    def __init__(self):
+        vars(self).update(self._get_crypto_impl())
+
+    @staticmethod
+    def _get_crypto_impl():
+        try:
+            from Cryptodome.Protocol import KDF  # noqa: F401
+            from Cryptodome.Cipher import AES  # noqa: F401
+            import Cryptodome.Random as Random  # noqa: F401
+        except ImportError:
+            from Crypto.Protocol import KDF  # noqa: F401
+            from Crypto.Cipher import AES  # noqa: F401
+            import Crypto.Random as Random  # noqa: F401
+        return locals()
+
     def _create_cipher(self, password, salt, IV):
         """
         Create the cipher object to encrypt or decrypt a payload.
         """
-        from Crypto.Protocol.KDF import PBKDF2
-        from Crypto.Cipher import AES
-
-        pw = PBKDF2(password, salt, dkLen=self.block_size)
-        return AES.new(pw[: self.block_size], AES.MODE_CFB, IV)
+        pw = self.KDF.PBKDF2(password, salt, dkLen=self.block_size)
+        return self.AES.new(pw[: self.block_size], self.AES.MODE_CFB, IV)
 
     def _get_new_password(self):
         while True:
@@ -68,21 +77,18 @@ class Encrypted(object):
 
 
 class EncryptedKeyring(Encrypted, Keyring):
-    """PyCrypto File Keyring"""
+    """PyCryptodome File Keyring"""
 
     filename = 'crypted_pass.cfg'
     pw_prefix = 'pw:'.encode()
 
-    @properties.ClassProperty
-    @classmethod
-    def priority(self):
+    @properties.classproperty
+    def priority(cls):
         "Applicable for all platforms, but not recommended."
         try:
-            __import__('Crypto.Cipher.AES')
-            __import__('Crypto.Protocol.KDF')
-            __import__('Crypto.Random')
+            cls._get_crypto_impl()
         except ImportError:  # pragma: no cover
-            raise RuntimeError("PyCrypto required")
+            raise RuntimeError("pycryptodome/x required")
         if not json:  # pragma: no cover
             raise RuntimeError("JSON implementation such as simplejson required.")
         return 0.6
@@ -193,12 +199,8 @@ class EncryptedKeyring(Encrypted, Keyring):
 
     def encrypt(self, password, assoc=None):
         # encrypt password, ignore associated data
-        from Crypto.Random import get_random_bytes
-
-        salt = get_random_bytes(self.block_size)
-        from Crypto.Cipher import AES
-
-        IV = get_random_bytes(AES.block_size)
+        salt = self.Random.get_random_bytes(self.block_size)
+        IV = self.Random.get_random_bytes(self.AES.block_size)
         cipher = self._create_cipher(self.keyring_key, salt, IV)
         password_encrypted = cipher.encrypt(self.pw_prefix + password)
         # Serialize the salt, IV, and encrypted password in a secure format
