@@ -3,9 +3,7 @@ import base64
 import unittest
 import pickle
 
-from six.moves import input
-
-from keyring.tests.test_backend import BackendBasicTests
+from keyring.testing.backend import BackendBasicTests
 from keyrings.alt import Google
 from keyring.credentials import SimpleCredential
 from keyring.backend import NullCrypter
@@ -338,7 +336,7 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
 
     def test_handles_broken_google_put_when_non_owner_update_fails(self):
         """Google Docs has a bug when putting to a non-owner
-           see  GoogleDocsKeyring._save_keyring()
+        see  GoogleDocsKeyring._save_keyring()
         """
         import gdata
 
@@ -375,7 +373,7 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
 
     def test_handles_broken_google_put_when_non_owner_update(self):
         """Google Docs has a bug when putting to a non-owner
-           see  GoogleDocsKeyring._save_keyring()
+        see  GoogleDocsKeyring._save_keyring()
         """
         import gdata
 
